Trait State Copy item path Source pub trait State: Sized {
Show 25 associated items type MembershipCoordinator ;
type Consensus ;
type Network ;
type StateManager ;
type Client ;
type VidDisperser ;
type VidReconstructor ;
type Vote1Collector ;
type Vote2Collector ;
type TimeoutCollector ;
type TimeoutOneHonestCollector ;
type CheckpointCollector ;
type EpochRootCollector ;
type EpochManager ;
type BlockBuilder ;
type ProposalValidator ;
type ShareValidator ;
type Storage ;
type Outbox ;
type CoordinatorOutbox ;
type PublicKey ;
type NodeId ;
type Timer ;
type CachedValidatedProposals ;
type CachedVidShares ;
}Expand description Builder’s type state specifies if members are set or not (unset).
You can use the associated types of this trait to control the state of individual members with the IsSet and IsUnset traits. You can change the state of the members with the Set* structs available in this module.
Type state of the member membership_coordinator.
It can implement either IsSet or IsUnset
Type state of the member consensus.
It can implement either IsSet or IsUnset
Type state of the member network.
It can implement either IsSet or IsUnset
Type state of the member state_manager.
It can implement either IsSet or IsUnset
Type state of the member client.
It can implement either IsSet or IsUnset
Type state of the member vid_disperser.
It can implement either IsSet or IsUnset
Type state of the member vid_reconstructor.
It can implement either IsSet or IsUnset
Type state of the member vote1_collector.
It can implement either IsSet or IsUnset
Type state of the member vote2_collector.
It can implement either IsSet or IsUnset
Type state of the member timeout_collector.
It can implement either IsSet or IsUnset
Type state of the member timeout_one_honest_collector.
It can implement either IsSet or IsUnset
Type state of the member checkpoint_collector.
It can implement either IsSet or IsUnset
Type state of the member epoch_root_collector.
It can implement either IsSet or IsUnset
Type state of the member epoch_manager.
It can implement either IsSet or IsUnset
Type state of the member block_builder.
It can implement either IsSet or IsUnset
Type state of the member proposal_validator.
It can implement either IsSet or IsUnset
Type state of the member share_validator.
It can implement either IsSet or IsUnset
Type state of the member storage.
It can implement either IsSet or IsUnset
Type state of the member outbox.
It can implement either IsSet or IsUnset
Type state of the member coordinator_outbox.
It can implement either IsSet or IsUnset
Type state of the member public_key.
It can implement either IsSet or IsUnset
Type state of the member node_id.
It can implement either IsSet or IsUnset
Type state of the member timer.
It can implement either IsSet or IsUnset
Type state of the member cached_validated_proposals.
It can implement either IsSet or IsUnset
Type state of the member cached_vid_shares.
It can implement either IsSet or IsUnset
This trait is not dyn compatible .
In older versions of Rust, dyn compatibility was called "object safety", so this trait is not object safe.